import React, { useState } from "react";
import styled from "styled-components";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faChevronDown } from "@fortawesome/free-solid-svg-icons";
import { px2rem } from "../../utils/getFontSize";
import { Container } from "../../Atoms/Container";
import { Spacer } from "../../Atoms/Spacer";

interface INavBar {
  menuItems: any;
  linkGap?: number;
  linkColor?: string;
  linkFontSize: number;
  subLinkFontSize: number;
  hoverColor: string;
}

const StyledNavBar = styled.div`
  width: fit-content;
`;

const StyledNavLink = styled.div<{ showSubMenu: boolean; hoverColor: string }>`
  margin-left: 40px;
  position: relative;
  cursor: pointer;
  width: fit-content;
  a {
    text-decoration: none;
  }
  span {
    :hover {
      ${({ hoverColor }) => hoverColor && `color: ${hoverColor} !important;`}
    }
  }
`;

const StyledIconWrapper = styled.span`
  margin-left: ${px2rem(8)};
  svg {
    :hover {
      opacity: 0.5;
    }
  }
`;

export const NavBar = ({
  menuItems,
  linkColor,
  linkFontSize,
  subLinkFontSize,
  hoverColor,
}: INavBar) => {
  const [showSubMenu, setShowSubMenu] = useState(false);
  const handleShowSubMenu = () => {
    setShowSubMenu(!showSubMenu);
  };

  return (
    <StyledNavBar>
      <Container flexRow>
        {menuItems.map(({ link, label, subMenu }: any) => (
          <StyledNavLink
            showSubMenu={subMenu}
            onClick={subMenu && handleShowSubMenu}
            hoverColor={hoverColor}
          >
            <>
              <a href={!subMenu && link}>
                <span
                  style={{
                    color: linkColor,
                    fontSize: px2rem(linkFontSize),
                  }}
                >
                  {label}
                  {subMenu && (
                    <StyledIconWrapper>
                      <FontAwesomeIcon icon={faChevronDown} size="xs" />
                    </StyledIconWrapper>
                  )}
                </span>
              </a>
              {showSubMenu && (
                <div
                  style={{
                    position: "absolute",
                    top: linkFontSize + 12,
                    left: 0,
                  }}
                >
                  <Container
                    width="200px"
                    padding={subMenu ? 16 : 0}
                    paddingRight={40}
                    backgroundColor="white"
                  >
                    {subMenu?.map(({ link, label }: any) => (
                      <div>
                        <a href={link}>
                          <span
                            style={{
                              color: linkColor,
                              fontSize: px2rem(subLinkFontSize),
                            }}
                          >
                            {label}
                          </span>
                        </a>
                        <Spacer height={16} />
                      </div>
                    ))}
                  </Container>
                </div>
              )}
            </>
          </StyledNavLink>
        ))}
      </Container>
    </StyledNavBar>
  );
};
